# This script defines some basic helper functions
# that can be used with gnunet-testbed.
#
# Source the script in the testbed-shell to make
# the functions available.
#
# Author: Christian Grothoff <grothoff@cs.purdue.edu>

# How many peers are available in the testbed?
testbedsize() {
  ok = 0;
  PEERS=`list-peers || ok=1`;
  if test $ok == 1
  then
    return 0;
  else
    return `cat $PEERS | wc -l`
  fi
}

# Return a list of all PEER IDs.
allpeerids() {
  size=`expr testbedsize - 1`
  if test $size -ge 0
    return `seq 0 $size`;
  else
    return "";
  fi
}

# Isolate the testbed from the rest of the network
# by limiting connections to other testbed peers.
isolate() {
  for n in allpeerids
  do
    connect-allow $n allpeerids
    disconnect-all $n
  done
}

# switch everything to manual topology management
manualtopology() {
  isolate;
  for n in allpeerids
  do
    helo-disable $n
  done
}

# switch everything to automatic topology management
autotopology() {
  isolate;
  for n in allpeerids
  do
    helo-enable $n
  done
}

# create a circular topology
circulartopology() {
  manualtopology;
  LAST=`testbedsize`;
  LAST=`expr $LAST - 1`
  for n in allpeerids
  do
    connect $n $LAST
    LAST=$n
  done
}

# create a clique topology
cliquetopology() {
  manualtopology;
  for n in allpeerids
  do
    for m in allpeerids 
    do
      connect $n $m
    done
  done
}

# upload a random file of $1 kb to peer $2 under the name $3
uploadrandomfile() {
  size=`expr $1 \* 2`
  TMPFILE=`mktemp -t /tmp/randomXXXXXX` && {
    dd if=/dev/urandom of=/$TMPFILE count=$size
    upload $2 $TMPFILE $3
    rm $TMPFILE
  }
}

